/*
* Licensed to the Apache Software Foundation (ASF) under one
* or more contributor license agreements.  See the NOTICE file
* distributed with this work for additional information
* regarding copyright ownership.  The ASF licenses this file
* to you under the Apache License, Version 2.0 (the
* "License"); you may not use this file except in compliance
* with the License.  You may obtain a copy of the License at
*
*   http://www.apache.org/licenses/LICENSE-2.0
*
* Unless required by applicable law or agreed to in writing,
* software distributed under the License is distributed on an
* "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
* KIND, either express or implied.  See the License for the
* specific language governing permissions and limitations
* under the License.
*/

package org.apache.samza.sql.interfaces;

import org.apache.samza.config.Config;


/**
 * Factory that is used to create {@link SqlIOResolver}.
 */
public interface SqlIOResolverFactory {

  /**
   * Create the {@link SqlIOResolver}. This is called during the application initialization.
   * @param resolverConfig config specifically supplied for this SqlIOResolver
   * @param fullConfig the full config object received by the application.
   * @return Returns the created {@link SqlIOResolver}
   */
  SqlIOResolver create(Config resolverConfig, Config fullConfig);
}
